@@ -1,4 +1,4 @@
 #!/bin/sh -e
 
 ./bootstrap
-./configure $*
+./configure "$@"
