@@ -1,4 +1,4 @@
-/*  $Id: AfternoonStalkerEngine.cpp,v 1.54 2017/12/09 18:31:57 sarrazip Exp $
+/*  $Id: AfternoonStalkerEngine.cpp,v 1.55 2024/04/08 03:43:44 sarrazip Exp $
     AfternoonStalkerEngine.cpp - A robot-killing video game engine.
 
     afternoonstalker - A robot-killing video game.
@@ -47,92 +47,6 @@
 using namespace std;
 
 
-/*  Tiles:
-*/
-
-#include "images/bunker_door_tile.xpm"
-#include "images/bunker_tile.xpm"
-#include "images/bunker_tile_0.xpm"
-#include "images/bunker_tile_1.xpm"
-#include "images/bunker_tile_2.xpm"
-#include "images/bunker_tile_3.xpm"
-#include "images/cobweb_tile.xpm"  /* foreground tile */
-#include "images/floor_tile.xpm"
-#include "images/wall_tile.xpm"
-#include "images/corner_tile_0.xpm"
-#include "images/corner_tile_1.xpm"
-#include "images/corner_tile_2.xpm"
-#include "images/corner_tile_3.xpm"
-#include "images/wall_end_tile_0.xpm"
-#include "images/wall_end_tile_1.xpm"
-#include "images/wall_end_tile_2.xpm"
-#include "images/wall_end_tile_3.xpm"
-
-
-/*  Sprite images:
-*/
-
-#include "images/human_front_0.xpm"
-#include "images/human_front_1.xpm"
-#include "images/human_front_2.xpm"
-#include "images/human_paralyzed_0.xpm"
-#include "images/human_explosion_0.xpm"
-#include "images/gray_robot_0.xpm"
-#include "images/gray_robot_1.xpm"
-#include "images/blue_robot_0.xpm"
-#include "images/blue_robot_1.xpm"
-#include "images/white_robot_0.xpm"
-#include "images/white_robot_1.xpm"
-#include "images/black_robot_0.xpm"
-#include "images/black_robot_1.xpm"
-#include "images/invisible_robot_0.xpm"
-#include "images/invisible_robot_1.xpm"
-
-#include "images/blink.xpm"
-#include "images/human_bullet.xpm"
-#include "images/robot_bullet.xpm"
-#include "images/big_robot_bullet_0.xpm"
-#include "images/big_robot_bullet_1.xpm"
-#include "images/big_robot_bullet_2.xpm"
-
-#include "images/gray_robot_explosion_0.xpm"
-#include "images/gray_robot_explosion_1.xpm"
-#include "images/blue_robot_explosion_0.xpm"
-#include "images/blue_robot_explosion_1.xpm"
-#include "images/white_robot_explosion_0.xpm"
-#include "images/white_robot_explosion_1.xpm"
-#include "images/black_robot_explosion_0.xpm"
-#include "images/black_robot_explosion_1.xpm"
-#include "images/invisible_robot_explosion_0.xpm"
-#include "images/invisible_robot_explosion_1.xpm"
-
-#include "images/gun.xpm"
-#include "images/spider_right_0.xpm"
-#include "images/spider_right_1.xpm"
-#include "images/spider_up_0.xpm"
-#include "images/spider_up_1.xpm"
-#include "images/spider_left_0.xpm"
-#include "images/spider_left_1.xpm"
-#include "images/spider_down_0.xpm"
-#include "images/spider_down_1.xpm"
-#include "images/spider_explosion_0.xpm"
-#include "images/bat_flying_0.xpm"
-#include "images/bat_flying_1.xpm"
-#include "images/bat_flying_2.xpm"
-#include "images/bat_flying_3.xpm"
-#include "images/bat_explosion_0.xpm"
-#include "images/digit0.xpm"
-#include "images/digit1.xpm"
-#include "images/digit2.xpm"
-#include "images/digit3.xpm"
-#include "images/digit4.xpm"
-#include "images/digit5.xpm"
-#include "images/digit6.xpm"
-#include "images/digit7.xpm"
-#include "images/digit8.xpm"
-#include "images/digit9.xpm"
-
-
 #ifdef _MSC_VER
     #if !defined(PACKAGE) || !defined(VERSION)
             #error PACKAGE and VERSION must be defined in the project
@@ -263,9 +177,11 @@ AfternoonStalkerEngine::AfternoonStalkerEngine(
                             bool fullScreen,
                             size_t _mazeIndex,
                             Rules _rules,
-                            bool processActiveEvent)
-  : GameEngine(Couple(640, 416), windowManagerCaption, fullScreen, processActiveEvent),
-                // may throw string exception
+                            bool processActiveEvent,
+                            bool useAcceleratedRendering)
+  : GameEngine(Couple(640, 416), windowManagerCaption, fullScreen, processActiveEvent, useAcceleratedRendering),
+        // true -> stray vertical lines appear in full screen mode when using software rendering.
+        // This constructor may throw an exception.
 
     paused(false),
     tickCount(0),
@@ -274,7 +190,7 @@ AfternoonStalkerEngine::AfternoonStalkerEngine(
     rules(_rules),
     mazeIndex(_mazeIndex),
 
-    blackColor(0),
+    blackColor(mapRGBA(0, 0, 0)),
 
     tilePA(17),
     tileMatrix(),
@@ -359,8 +275,6 @@ AfternoonStalkerEngine::AfternoonStalkerEngine(
     spiderKilledSound(),
     newLifeSound()
 {
-    blackColor = SDL_MapRGB(theSDLScreen->format, 0, 0, 0);
-
     try
     {
         try
@@ -455,24 +369,6 @@ AfternoonStalkerEngine::setTimeUntilNextAnimal()
 }
 
 
-static
-string
-getDir(const char *defaultValue, const char *envVarName)
-{
-    string dir;
-    const char *s = getenv(envVarName);
-    if (s != NULL)
-        dir = s;
-    else
-        dir = defaultValue;
-
-    if (!dir.empty() && dir[dir.length() - 1] != '/')
-        dir += '/';
-
-    return dir;
-}
-
-
 void
 AfternoonStalkerEngine::doOneTimeInitializations()
 /*  Throws an error message in a 'string' if an error occurs.
@@ -482,6 +378,7 @@ AfternoonStalkerEngine::doOneTimeInitializations()
     playerSprite = new Sprite(playerPA, initPlayerPos,
                                 Couple(0, 0), Couple(0, 0), Couple(4, 4),
                                 playerPA.getImageSize() - Couple(8, 8));
+    assert(playerSprite->getSize().isNonZero());
 
     loadLevel();  // requires that playerSprite be created
 
@@ -509,7 +406,7 @@ AfternoonStalkerEngine::initSounds()
         {
             try
             {
-                string pkgsounddir = getDir(PKGSOUNDDIR, "PKGSOUNDDIR");
+                string pkgsounddir = getDirPathFromEnv(PKGSOUNDDIR, "PKGSOUNDDIR");
 
                 gunPickupSound.init(pkgsounddir + "gun-pickup.wav");
                 playerBulletSound.init(pkgsounddir + "player-bullet.wav");
@@ -576,7 +473,7 @@ AfternoonStalkerEngine::initMenus()
     soundsMenu.setParentMenu(&optionsMenu);
 
     instructionsMenu.setTitle(
-        "Move with arrow keys or joystick. Shoot with Space, h-j-k-l, or A-B-X-Y.");
+        "Move with arrow keys or joystick. Shoot with Control, h-j-k-l, or A-B-X-Y.");
     instructionsMenu.addEntry("Back");
     instructionsMenu.setParentMenu(&mainMenu);
 
@@ -664,7 +561,7 @@ AfternoonStalkerEngine::processMenuMode()
                 case 0:  currentMenu = &rulesMenu; break;
                 case 1:  currentMenu = &mazeMenu; break;
                 case 2:  currentMenu = &soundsMenu; break;
-                case 3:  setVideoMode(theScreenSizeInPixels, !inFullScreenMode()); break;
+                case 3:  setFullScreenMode(!inFullScreenMode()); break;
                 case 4:  currentMenu = &mainMenu; break;
             }
         }
@@ -702,6 +599,21 @@ AfternoonStalkerEngine::processMenuMode()
 }
 
 
+void
+AfternoonStalkerEngine::dumpTileMatrix(ostream &out, const TileMatrix &tileMatrix)
+{
+    out << "Tile matrix: " << tileMatrix.size() << " rows of " << tileMatrix[0].size() << " columns:\n";
+    for (const TileMatrixRow &row : tileMatrix)
+    {
+        for (TileNo tileNo : row)
+        {
+            out << setw(4) << tileNo;
+        }
+        out << '\n';
+    }
+}
+
+
 void
 AfternoonStalkerEngine::loadLevel()
 /*  Loads the level described in the file designated by 'mazeIndex'.
@@ -717,7 +629,7 @@ AfternoonStalkerEngine::loadLevel()
 */
 {
     stringstream fullFilename;
-    fullFilename << getDir(PKGDATADIR, "PKGDATADIR") << "maze" << mazeIndex << ".set";
+    fullFilename << getDirPathFromEnv(PKGDATADIR, "PKGDATADIR") << "maze" << mazeIndex << ".set";
 
     ifstream setFile(fullFilename.str().c_str());
     if (!setFile)
@@ -878,7 +790,7 @@ AfternoonStalkerEngine::findSecondCobwebTile(size_t &x, size_t &y) const
 
 /*virtual*/
 void
-AfternoonStalkerEngine::processKey(SDLKey keysym, bool pressed)
+AfternoonStalkerEngine::processKey(SDL_Keycode keysym, bool pressed)
 {
     controller.processKey(keysym, pressed);
 }
@@ -888,12 +800,10 @@ AfternoonStalkerEngine::processKey(SDLKey keysym, bool pressed)
 void
 AfternoonStalkerEngine::processActivation(bool appActive)
 {
-    // If the app is now inactive, put the game in paused mode.
-    // If the app is now active, stay in paused mode so the user sees
-    // the resume prompt and can choose when to resume playing.
-    //
     if (!appActive)
     {
+        // The app is now inactive: Put the game in paused mode.
+        //
         if (numPlayerLives > 0)  // if in-game
         {
             setPauseMode();
@@ -904,8 +814,12 @@ AfternoonStalkerEngine::processActivation(bool appActive)
             displayCurrentMenu();
         }
     }
-    else if (numPlayerLives > 0)  // if in-game
-        paused = false;
+    else
+    {
+        // The app is now active: Stay in paused mode (paused == true)
+        // so that the user sees the resume prompt and can choose when
+        // to resume playing.
+    }
 }
 
 
@@ -926,7 +840,7 @@ AfternoonStalkerEngine::tick()
         setPauseMode();
 
     if (controller.isFullScreenToggleRequested())
-        setVideoMode(theScreenSizeInPixels, !inFullScreenMode());  // ignore failure
+        setFullScreenMode(!inFullScreenMode());  // ignore failure
 
     if (paused)
     {
@@ -1150,8 +1064,7 @@ AfternoonStalkerEngine::attemptMove(const Sprite &s,
     Returns a zero speed if no direction is allowed.
 
     's' must be the sprite that attempts to move from its current position.
-    The four 'attempt*' boolean parameters indicate which directions
-    are to be attempted.
+    'attemptedDirections' must indicate which directions are to be attempted.
     'speedFactor' must be the length of the move to try.
 */
 {
@@ -1631,7 +1544,8 @@ AfternoonStalkerEngine::animateAutomaticCharacters()
 
     /*  Show a gun if the player is out of bullets:
     */
-    if (numPlayerBullets == 0 && gunSprites.size() < 1 && numPlayerLives > 0)
+    static const char *noGun = getenv("NOGUN");
+    if (!noGun && numPlayerBullets == 0 && gunSprites.size() < 1 && numPlayerLives > 0)
     {
         Couple gunSize = gunPA.getImageSize();
 
@@ -2510,101 +2424,110 @@ AfternoonStalkerEngine::createScoreSprites(long n, Couple center)
 }
 
 
+void
+AfternoonStalkerEngine::loadPixmap(const char *filePath,
+                                   PixmapArray &pa,
+                                   size_t index)
+{
+    static const string dir = getDirPathFromEnv(PKGPIXMAPDIR, "PKGPIXMAPDIR");
+    GameEngine::loadPixmap(dir + filePath, pa, index);
+}
+
+
 void
 AfternoonStalkerEngine::loadPixmaps()
 {
     /*  Tiles:
     */
-    loadPixmap(wall_tile_xpm,        tilePA, WALL_TILE);
-    loadPixmap(corner_tile_0_xpm,    tilePA, CORNER0_TILE);
-    loadPixmap(corner_tile_1_xpm,    tilePA, CORNER1_TILE);
-    loadPixmap(corner_tile_2_xpm,    tilePA, CORNER2_TILE);
-    loadPixmap(corner_tile_3_xpm,    tilePA, CORNER3_TILE);
-    loadPixmap(wall_end_tile_0_xpm,  tilePA, WALLEND0_TILE);
-    loadPixmap(wall_end_tile_1_xpm,  tilePA, WALLEND1_TILE);
-    loadPixmap(wall_end_tile_2_xpm,  tilePA, WALLEND2_TILE);
-    loadPixmap(wall_end_tile_3_xpm,  tilePA, WALLEND3_TILE);
-    loadPixmap(floor_tile_xpm,       tilePA, FLOOR_TILE);
-    loadPixmap(cobweb_tile_xpm,      tilePA, COBWEB_TILE);
-    loadPixmap(bunker_tile_xpm,      tilePA, BUNKER_TILE);
-    loadPixmap(bunker_tile_0_xpm,    tilePA, BUNKER0_TILE);
-    loadPixmap(bunker_tile_1_xpm,    tilePA, BUNKER1_TILE);
-    loadPixmap(bunker_tile_2_xpm,    tilePA, BUNKER2_TILE);
-    loadPixmap(bunker_tile_3_xpm,    tilePA, BUNKER3_TILE);
-    loadPixmap(bunker_door_tile_xpm, tilePA, BUNKER_DOOR_TILE);
+    loadPixmap("wall_tile.xpm",        tilePA, WALL_TILE);
+    loadPixmap("corner_tile_0.xpm",    tilePA, CORNER0_TILE);
+    loadPixmap("corner_tile_1.xpm",    tilePA, CORNER1_TILE);
+    loadPixmap("corner_tile_2.xpm",    tilePA, CORNER2_TILE);
+    loadPixmap("corner_tile_3.xpm",    tilePA, CORNER3_TILE);
+    loadPixmap("wall_end_tile_0.xpm",  tilePA, WALLEND0_TILE);
+    loadPixmap("wall_end_tile_1.xpm",  tilePA, WALLEND1_TILE);
+    loadPixmap("wall_end_tile_2.xpm",  tilePA, WALLEND2_TILE);
+    loadPixmap("wall_end_tile_3.xpm",  tilePA, WALLEND3_TILE);
+    loadPixmap("floor_tile.xpm",       tilePA, FLOOR_TILE);
+    loadPixmap("cobweb_tile.xpm",      tilePA, COBWEB_TILE);
+    loadPixmap("bunker_tile.xpm",      tilePA, BUNKER_TILE);
+    loadPixmap("bunker_tile_0.xpm",    tilePA, BUNKER0_TILE);
+    loadPixmap("bunker_tile_1.xpm",    tilePA, BUNKER1_TILE);
+    loadPixmap("bunker_tile_2.xpm",    tilePA, BUNKER2_TILE);
+    loadPixmap("bunker_tile_3.xpm",    tilePA, BUNKER3_TILE);
+    loadPixmap("bunker_door_tile.xpm", tilePA, BUNKER_DOOR_TILE);
 
 
     /*  Sprites:
     */
-    loadPixmap(human_front_0_xpm, playerPA, 0);
-    loadPixmap(human_front_1_xpm, playerPA, 1);
-    loadPixmap(human_front_2_xpm, playerPA, 2);
-    loadPixmap(human_paralyzed_0_xpm, playerPA, 3);
-    loadPixmap(human_bullet_xpm, playerBulletPA, 0);
-    loadPixmap(robot_bullet_xpm, robotBulletPA, 0);
-    loadPixmap(big_robot_bullet_0_xpm, bigRobotBulletPA, 0);
-    loadPixmap(big_robot_bullet_1_xpm, bigRobotBulletPA, 1);
-    loadPixmap(big_robot_bullet_2_xpm, bigRobotBulletPA, 2);
-    loadPixmap(gun_xpm, gunPA, 0);
-    loadPixmap(human_explosion_0_xpm, playerExplosionPA, 0);
-    loadPixmap(gray_robot_0_xpm, grayRobotPA, 0);
-    loadPixmap(gray_robot_1_xpm, grayRobotPA, 1);
-    loadPixmap(blue_robot_0_xpm, blueRobotPA, 0);
-    loadPixmap(blue_robot_1_xpm, blueRobotPA, 1);
-    loadPixmap(white_robot_0_xpm, whiteRobotPA, 0);
-    loadPixmap(white_robot_1_xpm, whiteRobotPA, 1);
-    loadPixmap(black_robot_0_xpm, blackRobotPA, 0);
-    loadPixmap(black_robot_1_xpm, blackRobotPA, 1);
-    loadPixmap(invisible_robot_0_xpm, invisibleRobotPA, 0);
-    loadPixmap(invisible_robot_1_xpm, invisibleRobotPA, 1);
-    loadPixmap(blink_xpm, blinkPA, 0);
+    loadPixmap("human_front_0.xpm", playerPA, 0);
+    loadPixmap("human_front_1.xpm", playerPA, 1);
+    loadPixmap("human_front_2.xpm", playerPA, 2);
+    loadPixmap("human_paralyzed_0.xpm", playerPA, 3);
+    loadPixmap("human_bullet.xpm", playerBulletPA, 0);
+    loadPixmap("robot_bullet.xpm", robotBulletPA, 0);
+    loadPixmap("big_robot_bullet_0.xpm", bigRobotBulletPA, 0);
+    loadPixmap("big_robot_bullet_1.xpm", bigRobotBulletPA, 1);
+    loadPixmap("big_robot_bullet_2.xpm", bigRobotBulletPA, 2);
+    loadPixmap("gun.xpm", gunPA, 0);
+    loadPixmap("human_explosion_0.xpm", playerExplosionPA, 0);
+    loadPixmap("gray_robot_0.xpm", grayRobotPA, 0);
+    loadPixmap("gray_robot_1.xpm", grayRobotPA, 1);
+    loadPixmap("blue_robot_0.xpm", blueRobotPA, 0);
+    loadPixmap("blue_robot_1.xpm", blueRobotPA, 1);
+    loadPixmap("white_robot_0.xpm", whiteRobotPA, 0);
+    loadPixmap("white_robot_1.xpm", whiteRobotPA, 1);
+    loadPixmap("black_robot_0.xpm", blackRobotPA, 0);
+    loadPixmap("black_robot_1.xpm", blackRobotPA, 1);
+    loadPixmap("invisible_robot_0.xpm", invisibleRobotPA, 0);
+    loadPixmap("invisible_robot_1.xpm", invisibleRobotPA, 1);
+    loadPixmap("blink.xpm", blinkPA, 0);
 
-    loadPixmap(gray_robot_explosion_0_xpm, grayRobotExplosionPA, 0);
-    loadPixmap(gray_robot_explosion_1_xpm, grayRobotExplosionPA, 1);
-    loadPixmap(blue_robot_explosion_0_xpm, blueRobotExplosionPA, 0);
-    loadPixmap(blue_robot_explosion_1_xpm, blueRobotExplosionPA, 1);
-    loadPixmap(white_robot_explosion_0_xpm, whiteRobotExplosionPA, 0);
-    loadPixmap(white_robot_explosion_1_xpm, whiteRobotExplosionPA, 1);
-    loadPixmap(black_robot_explosion_0_xpm, blackRobotExplosionPA, 0);
-    loadPixmap(black_robot_explosion_1_xpm, blackRobotExplosionPA, 1);
-    loadPixmap(invisible_robot_explosion_0_xpm, invisibleRobotExplosionPA, 0);
-    loadPixmap(invisible_robot_explosion_1_xpm, invisibleRobotExplosionPA, 1);
+    loadPixmap("gray_robot_explosion_0.xpm", grayRobotExplosionPA, 0);
+    loadPixmap("gray_robot_explosion_1.xpm", grayRobotExplosionPA, 1);
+    loadPixmap("blue_robot_explosion_0.xpm", blueRobotExplosionPA, 0);
+    loadPixmap("blue_robot_explosion_1.xpm", blueRobotExplosionPA, 1);
+    loadPixmap("white_robot_explosion_0.xpm", whiteRobotExplosionPA, 0);
+    loadPixmap("white_robot_explosion_1.xpm", whiteRobotExplosionPA, 1);
+    loadPixmap("black_robot_explosion_0.xpm", blackRobotExplosionPA, 0);
+    loadPixmap("black_robot_explosion_1.xpm", blackRobotExplosionPA, 1);
+    loadPixmap("invisible_robot_explosion_0.xpm", invisibleRobotExplosionPA, 0);
+    loadPixmap("invisible_robot_explosion_1.xpm", invisibleRobotExplosionPA, 1);
 
 
     /*  Order of directions same as enum constants RIGHT, UP, LEFT, DOWN:
     */
-    loadPixmap(spider_right_0_xpm, spiderPA, 0);
-    loadPixmap(spider_right_1_xpm, spiderPA, 1);
-    loadPixmap(spider_up_0_xpm, spiderPA, 2);
-    loadPixmap(spider_up_1_xpm, spiderPA, 3);
-    loadPixmap(spider_left_0_xpm, spiderPA, 4);
-    loadPixmap(spider_left_1_xpm, spiderPA, 5);
-    loadPixmap(spider_down_0_xpm, spiderPA, 6);
-    loadPixmap(spider_down_1_xpm, spiderPA, 7);
+    loadPixmap("spider_right_0.xpm", spiderPA, 0);
+    loadPixmap("spider_right_1.xpm", spiderPA, 1);
+    loadPixmap("spider_up_0.xpm", spiderPA, 2);
+    loadPixmap("spider_up_1.xpm", spiderPA, 3);
+    loadPixmap("spider_left_0.xpm", spiderPA, 4);
+    loadPixmap("spider_left_1.xpm", spiderPA, 5);
+    loadPixmap("spider_down_0.xpm", spiderPA, 6);
+    loadPixmap("spider_down_1.xpm", spiderPA, 7);
 
-    loadPixmap(spider_explosion_0_xpm, spiderExplosionPA, 0);
+    loadPixmap("spider_explosion_0.xpm", spiderExplosionPA, 0);
 
+    loadPixmap("bat_flying_0.xpm", batPA, 0);
+    loadPixmap("bat_flying_1.xpm", batPA, 1);
+    loadPixmap("bat_flying_2.xpm", batPA, 2);
+    loadPixmap("bat_flying_3.xpm", batPA, 3);
 
-    loadPixmap(bat_flying_0_xpm, batPA, 0);
-    loadPixmap(bat_flying_1_xpm, batPA, 1);
-    loadPixmap(bat_flying_2_xpm, batPA, 2);
-    loadPixmap(bat_flying_3_xpm, batPA, 3);
-
-    loadPixmap(bat_explosion_0_xpm, batExplosionPA, 0);
+    loadPixmap("bat_explosion_0.xpm", batExplosionPA, 0);
 
 
     /*  Score digits:
     */
-    loadPixmap(digit0_xpm, digitPA, 0);
-    loadPixmap(digit1_xpm, digitPA, 1);
-    loadPixmap(digit2_xpm, digitPA, 2);
-    loadPixmap(digit3_xpm, digitPA, 3);
-    loadPixmap(digit4_xpm, digitPA, 4);
-    loadPixmap(digit5_xpm, digitPA, 5);
-    loadPixmap(digit6_xpm, digitPA, 6);
-    loadPixmap(digit7_xpm, digitPA, 7);
-    loadPixmap(digit8_xpm, digitPA, 8);
-    loadPixmap(digit9_xpm, digitPA, 9);
+    loadPixmap("digit0.xpm", digitPA, 0);
+    loadPixmap("digit1.xpm", digitPA, 1);
+    loadPixmap("digit2.xpm", digitPA, 2);
+    loadPixmap("digit3.xpm", digitPA, 3);
+    loadPixmap("digit4.xpm", digitPA, 4);
+    loadPixmap("digit5.xpm", digitPA, 5);
+    loadPixmap("digit6.xpm", digitPA, 6);
+    loadPixmap("digit7.xpm", digitPA, 7);
+    loadPixmap("digit8.xpm", digitPA, 8);
+    loadPixmap("digit9.xpm", digitPA, 9);
 }
 
 
@@ -2627,7 +2550,7 @@ AfternoonStalkerEngine::restoreBackground()
             TileNo tileNo = tileMatrix[y][x];
             if (tileNo == COBWEB_TILE)  // this is a foreground tile
                 tileNo = FLOOR_TILE;  // so we don't draw it now
-            SDL_Surface *p = tilePA.getImage(size_t(tileNo));
+            SDL_Texture *p = tilePA.getImage(size_t(tileNo));
             copyPixmap(p, dest);
         }
     }
@@ -2640,7 +2563,7 @@ AfternoonStalkerEngine::restoreForeground()
     const size_t levelHeight = tileMatrix.size();
     const size_t levelWidth = tileMatrix[0].size();
 
-    SDL_Surface *p = tilePA.getImage(COBWEB_TILE);  // only one foreground tile
+    SDL_Texture *p = tilePA.getImage(COBWEB_TILE);  // only one foreground tile
 
     size_t x, y;
     for (y = 0; y < levelHeight; y++)
