@@ -1,8 +1,8 @@
-/*  $Id: RobotSprite.cpp,v 1.6 2009/02/27 03:08:33 sarrazip Exp $
+/*  $Id: RobotSprite.cpp,v 1.8 2012/07/14 04:46:56 sarrazip Exp $
     RobotSprite.cpp - Sprite that represents a robot.
 
     afternoonstalker - A robot-killing video game.
-    Copyright (C) 2001-2009 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2012 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -14,10 +14,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    You should have received a copy of the GNU General Public
+    License along with this program; if not, write to the Free
+    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA  02110-1301, USA.
 */
 
 
@@ -25,10 +25,10 @@
 
 
 RobotSprite::RobotSprite(const PixmapArray &pixmapArray,
-			    const Couple &pos,
-			    const Couple &collBoxPos,
-			    const Couple &collBoxSize,
-			    const PixmapArray &explosionPA)
+                            const Couple &pos,
+                            const Couple &collBoxPos,
+                            const Couple &collBoxSize,
+                            const PixmapArray &explosionPA)
   : Sprite(pixmapArray, pos, Couple(), Couple(), collBoxPos, collBoxSize),
     timeOfLastShot(-1),
     smart(false),
@@ -50,7 +50,7 @@ void
 RobotSprite::startBlinking(PixmapArray &pa, unsigned long endOfBlinkTime)
 {
     blinkSprite = new Sprite(pa,
-			Couple(), Couple(), Couple(), Couple(), Couple());
+                        Couple(), Couple(), Couple(), Couple(), Couple());
     this->endOfBlinkTime = endOfBlinkTime;
 }
 
