@@ -1,8 +1,8 @@
-/*  $Id: RobotSprite.h,v 1.8 2009/02/27 03:08:33 sarrazip Exp $
+/*  $Id: RobotSprite.h,v 1.10 2012/07/14 04:46:56 sarrazip Exp $
     RobotSprite.h - Sprite that represents a robot.
 
     afternoonstalker - A robot-killing video game.
-    Copyright (C) 2001-2009 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2012 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -14,10 +14,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    You should have received a copy of the GNU General Public
+    License along with this program; if not, write to the Free
+    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA  02110-1301, USA.
 */
 
 #ifndef _H_RobotSprite
@@ -34,10 +34,10 @@ class RobotSprite : public Sprite
 {
 public:
     RobotSprite(const PixmapArray &pixmapArray,
-		const Couple &pos,
-		const Couple &collBoxPos,
-		const Couple &collBoxSize,
-		const PixmapArray &explosionPA);
+                const Couple &pos,
+                const Couple &collBoxPos,
+                const Couple &collBoxSize,
+                const PixmapArray &explosionPA);
     /*  Keeps a pointer to 'explosionPA'.
     */
 
@@ -45,30 +45,30 @@ public:
 
     long timeOfLastShot;
     /*  Time (in ticks) when the last bullet was shot by this robot.
-	Initialized by the constructor to -1, which means never.
+        Initialized by the constructor to -1, which means never.
     */
 
     bool smart;
     /*  Indicates if the robot is smart or not.
-	Initialized by the constructor to false.
+        Initialized by the constructor to false.
     */
 
     size_t numShotsBeforeDeath;
     /*  Number of shots that this robot must take before dying.
-	Initialized by the constructor to 1.
+        Initialized by the constructor to 1.
     */
 
     unsigned long endOfBlinkTime;
     /*  Time in ticks when this robot will stop blinking.
-	Initialized by the constructor to 0.
-	Any value that is inferior or equal to the game's "tickCount" means
-	no blinking.
+        Initialized by the constructor to 0.
+        Any value that is inferior or equal to the game's "tickCount" means
+        no blinking.
     */
 
     bool bigBullets;
-    /*	Indicates that this robot fires "big" bullets instead of the
-	normal ones.
-	Initialized by the constructor to false.
+    /*        Indicates that this robot fires "big" bullets instead of the
+        normal ones.
+        Initialized by the constructor to false.
     */
 
 
@@ -78,18 +78,18 @@ public:
 
     void startBlinking(PixmapArray &pa, unsigned long endOfBlinkTime);
     /*  Creates a Sprite with the given pixmap array that will represent
-	a blinking effect.
-	Sets the 'endOfBlinkTime' member to the given value.
+        a blinking effect.
+        Sets the 'endOfBlinkTime' member to the given value.
     */
 
     Sprite *getBlinkSprite() const;
     /*  Returns the blink sprite created by startBlinking(),
-	or NULL if none is currently present.
+        or NULL if none is currently present.
     */
 
     void stopBlinking();
     /*  Destroys the blink sprite if one is present.
-	Does nothing otherwise.
+        Does nothing otherwise.
     */
 
 private:
@@ -97,7 +97,7 @@ private:
     const PixmapArray *theExplosionPA;
     Sprite *blinkSprite;
 
-    /*	Forbidden operations:
+    /*        Forbidden operations:
     */
     RobotSprite(const RobotSprite &x);
     RobotSprite &operator = (const RobotSprite &x);
